# Create your views here.
from django_view_decorator import namespaced_decorator_factory

from membership.models import ServiceAccess
from services.registry import ServiceRegistry
from utils.view_utils import render


services_view = namespaced_decorator_factory(
    namespace="services",
    base_path="services",
)


@services_view(
    paths="",
    name="list",
    login_required=True,
)
def services_overview(request):
    active_services = [
        access.service_implementation
        for access in ServiceAccess.objects.filter(
            user=request.user,
        )
    ]

    active_service_classes = [service.__class__ for service in active_services]

    services = [
        service
        for _, service in ServiceRegistry.get_items()
        if service not in active_service_classes
    ]

    context = {
        "non_active_services": services,
        "active_services": active_services,
    }

    return render(
        request=request,
        template_name="services/services_overview.html",
        context=context,
    )


@services_view(
    paths="<str:service_slug>/",
    name="detail",
    login_required=True,
)
def service_detail(request, service_slug):
    service = ServiceRegistry.get(slug=service_slug)

    context = {
        "service": service,
    }

    return render(
        request=request,
        template_name="services/service_detail.html",
        context=context,
    )


@services_view(
    paths="<str:service_slug>/subscribe/",
    name="subscribe",
    login_required=True,
)
def service_subscribe(request, service_slug):
    service = ServiceRegistry.get(slug=service_slug)

    # TODO: add a form to subscribe to the service
    context = {
        "service": service,
        "base_path": "services:list",
        "form": service.get_form(),
    }

    return render(
        request=request,
        template_name="services/service_subscribe.html",
        context=context,
    )
